# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'HolidayCustomPeriodArgs',
    'HolidayCustomPeriodArgsDict',
    'OutlierDetectorAlgorithmArgs',
    'OutlierDetectorAlgorithmArgsDict',
    'OutlierDetectorAlgorithmConfigArgs',
    'OutlierDetectorAlgorithmConfigArgsDict',
]

MYPY = False

if not MYPY:
    class HolidayCustomPeriodArgsDict(TypedDict):
        end_time: pulumi.Input[builtins.str]
        start_time: pulumi.Input[builtins.str]
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        The name of the custom period.
        """
elif False:
    HolidayCustomPeriodArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class HolidayCustomPeriodArgs:
    def __init__(__self__, *,
                 end_time: pulumi.Input[builtins.str],
                 start_time: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] name: The name of the custom period.
        """
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "start_time", start_time)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the custom period.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class OutlierDetectorAlgorithmArgsDict(TypedDict):
        name: pulumi.Input[builtins.str]
        """
        The name of the algorithm to use ('mad' or 'dbscan').
        """
        sensitivity: pulumi.Input[builtins.float]
        """
        Specify the sensitivity of the detector (in range [0,1]).
        """
        config: NotRequired[pulumi.Input['OutlierDetectorAlgorithmConfigArgsDict']]
        """
        For DBSCAN only, specify the configuration map
        """
elif False:
    OutlierDetectorAlgorithmArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OutlierDetectorAlgorithmArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 sensitivity: pulumi.Input[builtins.float],
                 config: Optional[pulumi.Input['OutlierDetectorAlgorithmConfigArgs']] = None):
        """
        :param pulumi.Input[builtins.str] name: The name of the algorithm to use ('mad' or 'dbscan').
        :param pulumi.Input[builtins.float] sensitivity: Specify the sensitivity of the detector (in range [0,1]).
        :param pulumi.Input['OutlierDetectorAlgorithmConfigArgs'] config: For DBSCAN only, specify the configuration map
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "sensitivity", sensitivity)
        if config is not None:
            pulumi.set(__self__, "config", config)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the algorithm to use ('mad' or 'dbscan').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def sensitivity(self) -> pulumi.Input[builtins.float]:
        """
        Specify the sensitivity of the detector (in range [0,1]).
        """
        return pulumi.get(self, "sensitivity")

    @sensitivity.setter
    def sensitivity(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "sensitivity", value)

    @property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['OutlierDetectorAlgorithmConfigArgs']]:
        """
        For DBSCAN only, specify the configuration map
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['OutlierDetectorAlgorithmConfigArgs']]):
        pulumi.set(self, "config", value)


if not MYPY:
    class OutlierDetectorAlgorithmConfigArgsDict(TypedDict):
        epsilon: pulumi.Input[builtins.float]
        """
        Specify the epsilon parameter (positive float)
        """
elif False:
    OutlierDetectorAlgorithmConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OutlierDetectorAlgorithmConfigArgs:
    def __init__(__self__, *,
                 epsilon: pulumi.Input[builtins.float]):
        """
        :param pulumi.Input[builtins.float] epsilon: Specify the epsilon parameter (positive float)
        """
        pulumi.set(__self__, "epsilon", epsilon)

    @property
    @pulumi.getter
    def epsilon(self) -> pulumi.Input[builtins.float]:
        """
        Specify the epsilon parameter (positive float)
        """
        return pulumi.get(self, "epsilon")

    @epsilon.setter
    def epsilon(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "epsilon", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetProjectLimitsResult',
    'AwaitableGetProjectLimitsResult',
    'get_project_limits',
    'get_project_limits_output',
]

@pulumi.output_type
class GetProjectLimitsResult:
    """
    A collection of values returned by getProjectLimits.
    """
    def __init__(__self__, duration_max_per_test=None, id=None, project_id=None, vu_browser_max_per_test=None, vu_max_per_test=None, vuh_max_per_month=None):
        if duration_max_per_test and not isinstance(duration_max_per_test, int):
            raise TypeError("Expected argument 'duration_max_per_test' to be a int")
        pulumi.set(__self__, "duration_max_per_test", duration_max_per_test)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if vu_browser_max_per_test and not isinstance(vu_browser_max_per_test, int):
            raise TypeError("Expected argument 'vu_browser_max_per_test' to be a int")
        pulumi.set(__self__, "vu_browser_max_per_test", vu_browser_max_per_test)
        if vu_max_per_test and not isinstance(vu_max_per_test, int):
            raise TypeError("Expected argument 'vu_max_per_test' to be a int")
        pulumi.set(__self__, "vu_max_per_test", vu_max_per_test)
        if vuh_max_per_month and not isinstance(vuh_max_per_month, int):
            raise TypeError("Expected argument 'vuh_max_per_month' to be a int")
        pulumi.set(__self__, "vuh_max_per_month", vuh_max_per_month)

    @property
    @pulumi.getter(name="durationMaxPerTest")
    def duration_max_per_test(self) -> builtins.int:
        """
        Maximum duration of a test in seconds.
        """
        return pulumi.get(self, "duration_max_per_test")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The identifier of the project limits. This is set to the same as the project_id.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> builtins.str:
        """
        The identifier of the project to get limits for.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="vuBrowserMaxPerTest")
    def vu_browser_max_per_test(self) -> builtins.int:
        """
        Maximum number of concurrent browser virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_browser_max_per_test")

    @property
    @pulumi.getter(name="vuMaxPerTest")
    def vu_max_per_test(self) -> builtins.int:
        """
        Maximum number of concurrent virtual users (VUs) used in one test.
        """
        return pulumi.get(self, "vu_max_per_test")

    @property
    @pulumi.getter(name="vuhMaxPerMonth")
    def vuh_max_per_month(self) -> builtins.int:
        """
        Maximum amount of virtual user hours (VU/h) used per one calendar month.
        """
        return pulumi.get(self, "vuh_max_per_month")


class AwaitableGetProjectLimitsResult(GetProjectLimitsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectLimitsResult(
            duration_max_per_test=self.duration_max_per_test,
            id=self.id,
            project_id=self.project_id,
            vu_browser_max_per_test=self.vu_browser_max_per_test,
            vu_max_per_test=self.vu_max_per_test,
            vuh_max_per_month=self.vuh_max_per_month)


def get_project_limits(project_id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectLimitsResult:
    """
    Retrieves a k6 project limits.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test_project_limits = grafana.k6.Project("test_project_limits", name="Terraform Project Test Limits")
    from_project_id = grafana.k6.get_project_limits_output(project_id=test_project_limits.id)
    ```


    :param builtins.str project_id: The identifier of the project to get limits for.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:k6/getProjectLimits:getProjectLimits', __args__, opts=opts, typ=GetProjectLimitsResult).value

    return AwaitableGetProjectLimitsResult(
        duration_max_per_test=pulumi.get(__ret__, 'duration_max_per_test'),
        id=pulumi.get(__ret__, 'id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        vu_browser_max_per_test=pulumi.get(__ret__, 'vu_browser_max_per_test'),
        vu_max_per_test=pulumi.get(__ret__, 'vu_max_per_test'),
        vuh_max_per_month=pulumi.get(__ret__, 'vuh_max_per_month'))
def get_project_limits_output(project_id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectLimitsResult]:
    """
    Retrieves a k6 project limits.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test_project_limits = grafana.k6.Project("test_project_limits", name="Terraform Project Test Limits")
    from_project_id = grafana.k6.get_project_limits_output(project_id=test_project_limits.id)
    ```


    :param builtins.str project_id: The identifier of the project to get limits for.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:k6/getProjectLimits:getProjectLimits', __args__, opts=opts, typ=GetProjectLimitsResult)
    return __ret__.apply(lambda __response__: GetProjectLimitsResult(
        duration_max_per_test=pulumi.get(__response__, 'duration_max_per_test'),
        id=pulumi.get(__response__, 'id'),
        project_id=pulumi.get(__response__, 'project_id'),
        vu_browser_max_per_test=pulumi.get(__response__, 'vu_browser_max_per_test'),
        vu_max_per_test=pulumi.get(__response__, 'vu_max_per_test'),
        vuh_max_per_month=pulumi.get(__response__, 'vuh_max_per_month')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['OncallOnCallShiftArgs', 'OncallOnCallShift']

@pulumi.input_type
class OncallOnCallShiftArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[builtins.int],
                 start: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 by_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 by_monthdays: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 by_months: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 level: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 rolling_users: Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]] = None,
                 start_rotation_from_user_index: Optional[pulumi.Input[builtins.int]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 until: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_start: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a OncallOnCallShift resource.
        :param pulumi.Input[builtins.int] duration: The duration of the event.
        :param pulumi.Input[builtins.str] start: The start time of the on-call shift. This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[builtins.str] type: The shift's type. Can be rolling*users, recurrent*event, single_event
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] by_days: This parameter takes a list of days in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_monthdays: This parameter takes a list of days of the month.  Valid values are 1 to 31 or -31 to -1
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_months: This parameter takes a list of months. Valid values are 1 to 12
        :param pulumi.Input[builtins.str] frequency: The frequency of the event. Can be hourly, daily, weekly, monthly
        :param pulumi.Input[builtins.int] interval: The positive integer representing at which intervals the recurrence rule repeats.
        :param pulumi.Input[builtins.int] level: The priority level. The higher the value, the higher the priority.
        :param pulumi.Input[builtins.str] name: The shift's name.
        :param pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]] rolling_users: The list of lists with on-call users (for rolling_users event type)
        :param pulumi.Input[builtins.int] start_rotation_from_user_index: The index of the list of users in rolling_users, from which on-call rotation starts.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] time_zone: The shift's timezone.  Overrides schedule's timezone.
        :param pulumi.Input[builtins.str] until: The end time of recurrent on-call shifts (endless if null). This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] users: The list of on-call users (for single*event and recurrent*event event type).
        :param pulumi.Input[builtins.str] week_start: Start day of the week in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "start", start)
        pulumi.set(__self__, "type", type)
        if by_days is not None:
            pulumi.set(__self__, "by_days", by_days)
        if by_monthdays is not None:
            pulumi.set(__self__, "by_monthdays", by_monthdays)
        if by_months is not None:
            pulumi.set(__self__, "by_months", by_months)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rolling_users is not None:
            pulumi.set(__self__, "rolling_users", rolling_users)
        if start_rotation_from_user_index is not None:
            pulumi.set(__self__, "start_rotation_from_user_index", start_rotation_from_user_index)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)
        if until is not None:
            pulumi.set(__self__, "until", until)
        if users is not None:
            pulumi.set(__self__, "users", users)
        if week_start is not None:
            pulumi.set(__self__, "week_start", week_start)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Input[builtins.int]:
        """
        The duration of the event.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter
    def start(self) -> pulumi.Input[builtins.str]:
        """
        The start time of the on-call shift. This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        """
        return pulumi.get(self, "start")

    @start.setter
    def start(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "start", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        The shift's type. Can be rolling*users, recurrent*event, single_event
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="byDays")
    def by_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        This parameter takes a list of days in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        return pulumi.get(self, "by_days")

    @by_days.setter
    def by_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "by_days", value)

    @property
    @pulumi.getter(name="byMonthdays")
    def by_monthdays(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        This parameter takes a list of days of the month.  Valid values are 1 to 31 or -31 to -1
        """
        return pulumi.get(self, "by_monthdays")

    @by_monthdays.setter
    def by_monthdays(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "by_monthdays", value)

    @property
    @pulumi.getter(name="byMonths")
    def by_months(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        This parameter takes a list of months. Valid values are 1 to 12
        """
        return pulumi.get(self, "by_months")

    @by_months.setter
    def by_months(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "by_months", value)

    @property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The frequency of the event. Can be hourly, daily, weekly, monthly
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The positive integer representing at which intervals the recurrence rule repeats.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The priority level. The higher the value, the higher the priority.
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The shift's name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="rollingUsers")
    def rolling_users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]]:
        """
        The list of lists with on-call users (for rolling_users event type)
        """
        return pulumi.get(self, "rolling_users")

    @rolling_users.setter
    def rolling_users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]]):
        pulumi.set(self, "rolling_users", value)

    @property
    @pulumi.getter(name="startRotationFromUserIndex")
    def start_rotation_from_user_index(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The index of the list of users in rolling_users, from which on-call rotation starts.
        """
        return pulumi.get(self, "start_rotation_from_user_index")

    @start_rotation_from_user_index.setter
    def start_rotation_from_user_index(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "start_rotation_from_user_index", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The shift's timezone.  Overrides schedule's timezone.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "time_zone", value)

    @property
    @pulumi.getter
    def until(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The end time of recurrent on-call shifts (endless if null). This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        """
        return pulumi.get(self, "until")

    @until.setter
    def until(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "until", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The list of on-call users (for single*event and recurrent*event event type).
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "users", value)

    @property
    @pulumi.getter(name="weekStart")
    def week_start(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start day of the week in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        return pulumi.get(self, "week_start")

    @week_start.setter
    def week_start(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "week_start", value)


@pulumi.input_type
class _OncallOnCallShiftState:
    def __init__(__self__, *,
                 by_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 by_monthdays: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 by_months: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 duration: Optional[pulumi.Input[builtins.int]] = None,
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 level: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 rolling_users: Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]] = None,
                 start: Optional[pulumi.Input[builtins.str]] = None,
                 start_rotation_from_user_index: Optional[pulumi.Input[builtins.int]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 until: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_start: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering OncallOnCallShift resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] by_days: This parameter takes a list of days in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_monthdays: This parameter takes a list of days of the month.  Valid values are 1 to 31 or -31 to -1
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_months: This parameter takes a list of months. Valid values are 1 to 12
        :param pulumi.Input[builtins.int] duration: The duration of the event.
        :param pulumi.Input[builtins.str] frequency: The frequency of the event. Can be hourly, daily, weekly, monthly
        :param pulumi.Input[builtins.int] interval: The positive integer representing at which intervals the recurrence rule repeats.
        :param pulumi.Input[builtins.int] level: The priority level. The higher the value, the higher the priority.
        :param pulumi.Input[builtins.str] name: The shift's name.
        :param pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]] rolling_users: The list of lists with on-call users (for rolling_users event type)
        :param pulumi.Input[builtins.str] start: The start time of the on-call shift. This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[builtins.int] start_rotation_from_user_index: The index of the list of users in rolling_users, from which on-call rotation starts.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] time_zone: The shift's timezone.  Overrides schedule's timezone.
        :param pulumi.Input[builtins.str] type: The shift's type. Can be rolling*users, recurrent*event, single_event
        :param pulumi.Input[builtins.str] until: The end time of recurrent on-call shifts (endless if null). This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] users: The list of on-call users (for single*event and recurrent*event event type).
        :param pulumi.Input[builtins.str] week_start: Start day of the week in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        if by_days is not None:
            pulumi.set(__self__, "by_days", by_days)
        if by_monthdays is not None:
            pulumi.set(__self__, "by_monthdays", by_monthdays)
        if by_months is not None:
            pulumi.set(__self__, "by_months", by_months)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if interval is not None:
            pulumi.set(__self__, "interval", interval)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rolling_users is not None:
            pulumi.set(__self__, "rolling_users", rolling_users)
        if start is not None:
            pulumi.set(__self__, "start", start)
        if start_rotation_from_user_index is not None:
            pulumi.set(__self__, "start_rotation_from_user_index", start_rotation_from_user_index)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if until is not None:
            pulumi.set(__self__, "until", until)
        if users is not None:
            pulumi.set(__self__, "users", users)
        if week_start is not None:
            pulumi.set(__self__, "week_start", week_start)

    @property
    @pulumi.getter(name="byDays")
    def by_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        This parameter takes a list of days in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        return pulumi.get(self, "by_days")

    @by_days.setter
    def by_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "by_days", value)

    @property
    @pulumi.getter(name="byMonthdays")
    def by_monthdays(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        This parameter takes a list of days of the month.  Valid values are 1 to 31 or -31 to -1
        """
        return pulumi.get(self, "by_monthdays")

    @by_monthdays.setter
    def by_monthdays(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "by_monthdays", value)

    @property
    @pulumi.getter(name="byMonths")
    def by_months(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]:
        """
        This parameter takes a list of months. Valid values are 1 to 12
        """
        return pulumi.get(self, "by_months")

    @by_months.setter
    def by_months(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]]):
        pulumi.set(self, "by_months", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The duration of the event.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The frequency of the event. Can be hourly, daily, weekly, monthly
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter
    def interval(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The positive integer representing at which intervals the recurrence rule repeats.
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "interval", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The priority level. The higher the value, the higher the priority.
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The shift's name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="rollingUsers")
    def rolling_users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]]:
        """
        The list of lists with on-call users (for rolling_users event type)
        """
        return pulumi.get(self, "rolling_users")

    @rolling_users.setter
    def rolling_users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]]):
        pulumi.set(self, "rolling_users", value)

    @property
    @pulumi.getter
    def start(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The start time of the on-call shift. This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        """
        return pulumi.get(self, "start")

    @start.setter
    def start(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start", value)

    @property
    @pulumi.getter(name="startRotationFromUserIndex")
    def start_rotation_from_user_index(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The index of the list of users in rolling_users, from which on-call rotation starts.
        """
        return pulumi.get(self, "start_rotation_from_user_index")

    @start_rotation_from_user_index.setter
    def start_rotation_from_user_index(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "start_rotation_from_user_index", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The shift's timezone.  Overrides schedule's timezone.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "time_zone", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The shift's type. Can be rolling*users, recurrent*event, single_event
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def until(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The end time of recurrent on-call shifts (endless if null). This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        """
        return pulumi.get(self, "until")

    @until.setter
    def until(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "until", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The list of on-call users (for single*event and recurrent*event event type).
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "users", value)

    @property
    @pulumi.getter(name="weekStart")
    def week_start(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Start day of the week in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        return pulumi.get(self, "week_start")

    @week_start.setter
    def week_start(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "week_start", value)


warnings.warn("""grafana.index/oncalloncallshift.OncallOnCallShift has been deprecated in favor of grafana.oncall/oncallshift.OnCallShift""", DeprecationWarning)


@pulumi.type_token("grafana:index/oncallOnCallShift:OncallOnCallShift")
class OncallOnCallShift(pulumi.CustomResource):
    warnings.warn("""grafana.index/oncalloncallshift.OncallOnCallShift has been deprecated in favor of grafana.oncall/oncallshift.OnCallShift""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 by_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 by_monthdays: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 by_months: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 duration: Optional[pulumi.Input[builtins.int]] = None,
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 level: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 rolling_users: Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]] = None,
                 start: Optional[pulumi.Input[builtins.str]] = None,
                 start_rotation_from_user_index: Optional[pulumi.Input[builtins.int]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 until: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_start: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/on_call_shifts/)

        ## Import

        ```sh
        $ pulumi import grafana:index/oncallOnCallShift:OncallOnCallShift name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] by_days: This parameter takes a list of days in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_monthdays: This parameter takes a list of days of the month.  Valid values are 1 to 31 or -31 to -1
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_months: This parameter takes a list of months. Valid values are 1 to 12
        :param pulumi.Input[builtins.int] duration: The duration of the event.
        :param pulumi.Input[builtins.str] frequency: The frequency of the event. Can be hourly, daily, weekly, monthly
        :param pulumi.Input[builtins.int] interval: The positive integer representing at which intervals the recurrence rule repeats.
        :param pulumi.Input[builtins.int] level: The priority level. The higher the value, the higher the priority.
        :param pulumi.Input[builtins.str] name: The shift's name.
        :param pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]] rolling_users: The list of lists with on-call users (for rolling_users event type)
        :param pulumi.Input[builtins.str] start: The start time of the on-call shift. This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[builtins.int] start_rotation_from_user_index: The index of the list of users in rolling_users, from which on-call rotation starts.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] time_zone: The shift's timezone.  Overrides schedule's timezone.
        :param pulumi.Input[builtins.str] type: The shift's type. Can be rolling*users, recurrent*event, single_event
        :param pulumi.Input[builtins.str] until: The end time of recurrent on-call shifts (endless if null). This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] users: The list of on-call users (for single*event and recurrent*event event type).
        :param pulumi.Input[builtins.str] week_start: Start day of the week in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OncallOnCallShiftArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/on_call_shifts/)

        ## Import

        ```sh
        $ pulumi import grafana:index/oncallOnCallShift:OncallOnCallShift name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param OncallOnCallShiftArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OncallOnCallShiftArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 by_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 by_monthdays: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 by_months: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
                 duration: Optional[pulumi.Input[builtins.int]] = None,
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 interval: Optional[pulumi.Input[builtins.int]] = None,
                 level: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 rolling_users: Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]] = None,
                 start: Optional[pulumi.Input[builtins.str]] = None,
                 start_rotation_from_user_index: Optional[pulumi.Input[builtins.int]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 until: Optional[pulumi.Input[builtins.str]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 week_start: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""OncallOnCallShift is deprecated: grafana.index/oncalloncallshift.OncallOnCallShift has been deprecated in favor of grafana.oncall/oncallshift.OnCallShift""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OncallOnCallShiftArgs.__new__(OncallOnCallShiftArgs)

            __props__.__dict__["by_days"] = by_days
            __props__.__dict__["by_monthdays"] = by_monthdays
            __props__.__dict__["by_months"] = by_months
            if duration is None and not opts.urn:
                raise TypeError("Missing required property 'duration'")
            __props__.__dict__["duration"] = duration
            __props__.__dict__["frequency"] = frequency
            __props__.__dict__["interval"] = interval
            __props__.__dict__["level"] = level
            __props__.__dict__["name"] = name
            __props__.__dict__["rolling_users"] = rolling_users
            if start is None and not opts.urn:
                raise TypeError("Missing required property 'start'")
            __props__.__dict__["start"] = start
            __props__.__dict__["start_rotation_from_user_index"] = start_rotation_from_user_index
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["time_zone"] = time_zone
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["until"] = until
            __props__.__dict__["users"] = users
            __props__.__dict__["week_start"] = week_start
        super(OncallOnCallShift, __self__).__init__(
            'grafana:index/oncallOnCallShift:OncallOnCallShift',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            by_days: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            by_monthdays: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
            by_months: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.int]]]] = None,
            duration: Optional[pulumi.Input[builtins.int]] = None,
            frequency: Optional[pulumi.Input[builtins.str]] = None,
            interval: Optional[pulumi.Input[builtins.int]] = None,
            level: Optional[pulumi.Input[builtins.int]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            rolling_users: Optional[pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]]] = None,
            start: Optional[pulumi.Input[builtins.str]] = None,
            start_rotation_from_user_index: Optional[pulumi.Input[builtins.int]] = None,
            team_id: Optional[pulumi.Input[builtins.str]] = None,
            time_zone: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            until: Optional[pulumi.Input[builtins.str]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            week_start: Optional[pulumi.Input[builtins.str]] = None) -> 'OncallOnCallShift':
        """
        Get an existing OncallOnCallShift resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] by_days: This parameter takes a list of days in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_monthdays: This parameter takes a list of days of the month.  Valid values are 1 to 31 or -31 to -1
        :param pulumi.Input[Sequence[pulumi.Input[builtins.int]]] by_months: This parameter takes a list of months. Valid values are 1 to 12
        :param pulumi.Input[builtins.int] duration: The duration of the event.
        :param pulumi.Input[builtins.str] frequency: The frequency of the event. Can be hourly, daily, weekly, monthly
        :param pulumi.Input[builtins.int] interval: The positive integer representing at which intervals the recurrence rule repeats.
        :param pulumi.Input[builtins.int] level: The priority level. The higher the value, the higher the priority.
        :param pulumi.Input[builtins.str] name: The shift's name.
        :param pulumi.Input[Sequence[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]] rolling_users: The list of lists with on-call users (for rolling_users event type)
        :param pulumi.Input[builtins.str] start: The start time of the on-call shift. This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[builtins.int] start_rotation_from_user_index: The index of the list of users in rolling_users, from which on-call rotation starts.
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] time_zone: The shift's timezone.  Overrides schedule's timezone.
        :param pulumi.Input[builtins.str] type: The shift's type. Can be rolling*users, recurrent*event, single_event
        :param pulumi.Input[builtins.str] until: The end time of recurrent on-call shifts (endless if null). This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] users: The list of on-call users (for single*event and recurrent*event event type).
        :param pulumi.Input[builtins.str] week_start: Start day of the week in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OncallOnCallShiftState.__new__(_OncallOnCallShiftState)

        __props__.__dict__["by_days"] = by_days
        __props__.__dict__["by_monthdays"] = by_monthdays
        __props__.__dict__["by_months"] = by_months
        __props__.__dict__["duration"] = duration
        __props__.__dict__["frequency"] = frequency
        __props__.__dict__["interval"] = interval
        __props__.__dict__["level"] = level
        __props__.__dict__["name"] = name
        __props__.__dict__["rolling_users"] = rolling_users
        __props__.__dict__["start"] = start
        __props__.__dict__["start_rotation_from_user_index"] = start_rotation_from_user_index
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["time_zone"] = time_zone
        __props__.__dict__["type"] = type
        __props__.__dict__["until"] = until
        __props__.__dict__["users"] = users
        __props__.__dict__["week_start"] = week_start
        return OncallOnCallShift(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="byDays")
    def by_days(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        This parameter takes a list of days in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        return pulumi.get(self, "by_days")

    @property
    @pulumi.getter(name="byMonthdays")
    def by_monthdays(self) -> pulumi.Output[Optional[Sequence[builtins.int]]]:
        """
        This parameter takes a list of days of the month.  Valid values are 1 to 31 or -31 to -1
        """
        return pulumi.get(self, "by_monthdays")

    @property
    @pulumi.getter(name="byMonths")
    def by_months(self) -> pulumi.Output[Optional[Sequence[builtins.int]]]:
        """
        This parameter takes a list of months. Valid values are 1 to 12
        """
        return pulumi.get(self, "by_months")

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[builtins.int]:
        """
        The duration of the event.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The frequency of the event. Can be hourly, daily, weekly, monthly
        """
        return pulumi.get(self, "frequency")

    @property
    @pulumi.getter
    def interval(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The positive integer representing at which intervals the recurrence rule repeats.
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter
    def level(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The priority level. The higher the value, the higher the priority.
        """
        return pulumi.get(self, "level")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The shift's name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="rollingUsers")
    def rolling_users(self) -> pulumi.Output[Optional[Sequence[Sequence[builtins.str]]]]:
        """
        The list of lists with on-call users (for rolling_users event type)
        """
        return pulumi.get(self, "rolling_users")

    @property
    @pulumi.getter
    def start(self) -> pulumi.Output[builtins.str]:
        """
        The start time of the on-call shift. This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        """
        return pulumi.get(self, "start")

    @property
    @pulumi.getter(name="startRotationFromUserIndex")
    def start_rotation_from_user_index(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The index of the list of users in rolling_users, from which on-call rotation starts.
        """
        return pulumi.get(self, "start_rotation_from_user_index")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The shift's timezone.  Overrides schedule's timezone.
        """
        return pulumi.get(self, "time_zone")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        The shift's type. Can be rolling*users, recurrent*event, single_event
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def until(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The end time of recurrent on-call shifts (endless if null). This parameter takes a date format as yyyy-MM-dd'T'HH:mm:ss (for example "2020-09-05T08:00:00")
        """
        return pulumi.get(self, "until")

    @property
    @pulumi.getter
    def users(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        The list of on-call users (for single*event and recurrent*event event type).
        """
        return pulumi.get(self, "users")

    @property
    @pulumi.getter(name="weekStart")
    def week_start(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Start day of the week in iCal format. Can be MO, TU, WE, TH, FR, SA, SU
        """
        return pulumi.get(self, "week_start")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetCloudIpsResult',
    'AwaitableGetCloudIpsResult',
    'get_cloud_ips',
    'get_cloud_ips_output',
]

warnings.warn("""grafana.index/getcloudips.getCloudIps has been deprecated in favor of grafana.cloud/getips.getIps""", DeprecationWarning)

@pulumi.output_type
class GetCloudIpsResult:
    """
    A collection of values returned by getCloudIps.
    """
    def __init__(__self__, hosted_alerts=None, hosted_grafanas=None, hosted_logs=None, hosted_metrics=None, hosted_traces=None, id=None):
        if hosted_alerts and not isinstance(hosted_alerts, list):
            raise TypeError("Expected argument 'hosted_alerts' to be a list")
        pulumi.set(__self__, "hosted_alerts", hosted_alerts)
        if hosted_grafanas and not isinstance(hosted_grafanas, list):
            raise TypeError("Expected argument 'hosted_grafanas' to be a list")
        pulumi.set(__self__, "hosted_grafanas", hosted_grafanas)
        if hosted_logs and not isinstance(hosted_logs, list):
            raise TypeError("Expected argument 'hosted_logs' to be a list")
        pulumi.set(__self__, "hosted_logs", hosted_logs)
        if hosted_metrics and not isinstance(hosted_metrics, list):
            raise TypeError("Expected argument 'hosted_metrics' to be a list")
        pulumi.set(__self__, "hosted_metrics", hosted_metrics)
        if hosted_traces and not isinstance(hosted_traces, list):
            raise TypeError("Expected argument 'hosted_traces' to be a list")
        pulumi.set(__self__, "hosted_traces", hosted_traces)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="hostedAlerts")
    def hosted_alerts(self) -> Sequence[builtins.str]:
        """
        Set of IP addresses that are used for hosted alerts.
        """
        return pulumi.get(self, "hosted_alerts")

    @property
    @pulumi.getter(name="hostedGrafanas")
    def hosted_grafanas(self) -> Sequence[builtins.str]:
        """
        Set of IP addresses that are used for hosted Grafana.
        """
        return pulumi.get(self, "hosted_grafanas")

    @property
    @pulumi.getter(name="hostedLogs")
    def hosted_logs(self) -> Sequence[builtins.str]:
        """
        Set of IP addresses that are used for hosted logs.
        """
        return pulumi.get(self, "hosted_logs")

    @property
    @pulumi.getter(name="hostedMetrics")
    def hosted_metrics(self) -> Sequence[builtins.str]:
        """
        Set of IP addresses that are used for hosted metrics.
        """
        return pulumi.get(self, "hosted_metrics")

    @property
    @pulumi.getter(name="hostedTraces")
    def hosted_traces(self) -> Sequence[builtins.str]:
        """
        Set of IP addresses that are used for hosted traces.
        """
        return pulumi.get(self, "hosted_traces")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetCloudIpsResult(GetCloudIpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudIpsResult(
            hosted_alerts=self.hosted_alerts,
            hosted_grafanas=self.hosted_grafanas,
            hosted_logs=self.hosted_logs,
            hosted_metrics=self.hosted_metrics,
            hosted_traces=self.hosted_traces,
            id=self.id)


def get_cloud_ips(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudIpsResult:
    """
    Data source for retrieving sets of cloud IPs. See https://grafana.com/docs/grafana-cloud/reference/allow-list/ for more info

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.cloud.get_ips()
    ```
    """
    pulumi.log.warn("""get_cloud_ips is deprecated: grafana.index/getcloudips.getCloudIps has been deprecated in favor of grafana.cloud/getips.getIps""")
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getCloudIps:getCloudIps', __args__, opts=opts, typ=GetCloudIpsResult).value

    return AwaitableGetCloudIpsResult(
        hosted_alerts=pulumi.get(__ret__, 'hosted_alerts'),
        hosted_grafanas=pulumi.get(__ret__, 'hosted_grafanas'),
        hosted_logs=pulumi.get(__ret__, 'hosted_logs'),
        hosted_metrics=pulumi.get(__ret__, 'hosted_metrics'),
        hosted_traces=pulumi.get(__ret__, 'hosted_traces'),
        id=pulumi.get(__ret__, 'id'))
def get_cloud_ips_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudIpsResult]:
    """
    Data source for retrieving sets of cloud IPs. See https://grafana.com/docs/grafana-cloud/reference/allow-list/ for more info

    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.cloud.get_ips()
    ```
    """
    pulumi.log.warn("""get_cloud_ips is deprecated: grafana.index/getcloudips.getCloudIps has been deprecated in favor of grafana.cloud/getips.getIps""")
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getCloudIps:getCloudIps', __args__, opts=opts, typ=GetCloudIpsResult)
    return __ret__.apply(lambda __response__: GetCloudIpsResult(
        hosted_alerts=pulumi.get(__response__, 'hosted_alerts'),
        hosted_grafanas=pulumi.get(__response__, 'hosted_grafanas'),
        hosted_logs=pulumi.get(__response__, 'hosted_logs'),
        hosted_metrics=pulumi.get(__response__, 'hosted_metrics'),
        hosted_traces=pulumi.get(__response__, 'hosted_traces'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDashboardsResult',
    'AwaitableGetDashboardsResult',
    'get_dashboards',
    'get_dashboards_output',
]

warnings.warn("""grafana.index/getdashboards.getDashboards has been deprecated in favor of grafana.oss/getdashboards.getDashboards""", DeprecationWarning)

@pulumi.output_type
class GetDashboardsResult:
    """
    A collection of values returned by getDashboards.
    """
    def __init__(__self__, dashboards=None, folder_uids=None, id=None, limit=None, org_id=None, tags=None):
        if dashboards and not isinstance(dashboards, list):
            raise TypeError("Expected argument 'dashboards' to be a list")
        pulumi.set(__self__, "dashboards", dashboards)
        if folder_uids and not isinstance(folder_uids, list):
            raise TypeError("Expected argument 'folder_uids' to be a list")
        pulumi.set(__self__, "folder_uids", folder_uids)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if limit and not isinstance(limit, int):
            raise TypeError("Expected argument 'limit' to be a int")
        pulumi.set(__self__, "limit", limit)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def dashboards(self) -> Sequence['outputs.GetDashboardsDashboardResult']:
        return pulumi.get(self, "dashboards")

    @property
    @pulumi.getter(name="folderUids")
    def folder_uids(self) -> Optional[Sequence[builtins.str]]:
        """
        UIDs of Grafana folders containing dashboards. Specify to filter for dashboards by folder (eg. `["General"]` for General folder), or leave blank to get all dashboards in all folders.
        """
        return pulumi.get(self, "folder_uids")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def limit(self) -> Optional[builtins.int]:
        """
        Maximum number of dashboard search results to return. Defaults to `5000`.
        """
        return pulumi.get(self, "limit")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[builtins.str]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[builtins.str]]:
        """
        List of string Grafana dashboard tags to search for, eg. `["prod"]`. Used only as search input, i.e., attribute value will remain unchanged.
        """
        return pulumi.get(self, "tags")


class AwaitableGetDashboardsResult(GetDashboardsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDashboardsResult(
            dashboards=self.dashboards,
            folder_uids=self.folder_uids,
            id=self.id,
            limit=self.limit,
            org_id=self.org_id,
            tags=self.tags)


def get_dashboards(folder_uids: Optional[Sequence[builtins.str]] = None,
                   limit: Optional[builtins.int] = None,
                   org_id: Optional[builtins.str] = None,
                   tags: Optional[Sequence[builtins.str]] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDashboardsResult:
    """
    Datasource for retrieving all dashboards. Specify list of folder IDs to search in for dashboards.

    * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/)
    * [Folder/Dashboard Search HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder_dashboard_search/)
    * [Dashboard HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/dashboard/)


    :param Sequence[builtins.str] folder_uids: UIDs of Grafana folders containing dashboards. Specify to filter for dashboards by folder (eg. `["General"]` for General folder), or leave blank to get all dashboards in all folders.
    :param builtins.int limit: Maximum number of dashboard search results to return. Defaults to `5000`.
    :param builtins.str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    :param Sequence[builtins.str] tags: List of string Grafana dashboard tags to search for, eg. `["prod"]`. Used only as search input, i.e., attribute value will remain unchanged.
    """
    pulumi.log.warn("""get_dashboards is deprecated: grafana.index/getdashboards.getDashboards has been deprecated in favor of grafana.oss/getdashboards.getDashboards""")
    __args__ = dict()
    __args__['folderUids'] = folder_uids
    __args__['limit'] = limit
    __args__['orgId'] = org_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:index/getDashboards:getDashboards', __args__, opts=opts, typ=GetDashboardsResult).value

    return AwaitableGetDashboardsResult(
        dashboards=pulumi.get(__ret__, 'dashboards'),
        folder_uids=pulumi.get(__ret__, 'folder_uids'),
        id=pulumi.get(__ret__, 'id'),
        limit=pulumi.get(__ret__, 'limit'),
        org_id=pulumi.get(__ret__, 'org_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_dashboards_output(folder_uids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                          limit: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                          org_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          tags: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDashboardsResult]:
    """
    Datasource for retrieving all dashboards. Specify list of folder IDs to search in for dashboards.

    * [Official documentation](https://grafana.com/docs/grafana/latest/dashboards/)
    * [Folder/Dashboard Search HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/folder_dashboard_search/)
    * [Dashboard HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/dashboard/)


    :param Sequence[builtins.str] folder_uids: UIDs of Grafana folders containing dashboards. Specify to filter for dashboards by folder (eg. `["General"]` for General folder), or leave blank to get all dashboards in all folders.
    :param builtins.int limit: Maximum number of dashboard search results to return. Defaults to `5000`.
    :param builtins.str org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
    :param Sequence[builtins.str] tags: List of string Grafana dashboard tags to search for, eg. `["prod"]`. Used only as search input, i.e., attribute value will remain unchanged.
    """
    pulumi.log.warn("""get_dashboards is deprecated: grafana.index/getdashboards.getDashboards has been deprecated in favor of grafana.oss/getdashboards.getDashboards""")
    __args__ = dict()
    __args__['folderUids'] = folder_uids
    __args__['limit'] = limit
    __args__['orgId'] = org_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:index/getDashboards:getDashboards', __args__, opts=opts, typ=GetDashboardsResult)
    return __ret__.apply(lambda __response__: GetDashboardsResult(
        dashboards=pulumi.get(__response__, 'dashboards'),
        folder_uids=pulumi.get(__response__, 'folder_uids'),
        id=pulumi.get(__response__, 'id'),
        limit=pulumi.get(__response__, 'limit'),
        org_id=pulumi.get(__response__, 'org_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RoleAssignmentItemArgs', 'RoleAssignmentItem']

@pulumi.input_type
class RoleAssignmentItemArgs:
    def __init__(__self__, *,
                 role_uid: pulumi.Input[builtins.str],
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a RoleAssignmentItem resource.
        :param pulumi.Input[builtins.str] role_uid: the role UID onto which to assign an actor
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        :param pulumi.Input[builtins.str] service_account_id: the service account onto which the role is to be assigned
        :param pulumi.Input[builtins.str] team_id: the team onto which the role is to be assigned
        :param pulumi.Input[builtins.str] user_id: the user onto which the role is to be assigned
        """
        pulumi.set(__self__, "role_uid", role_uid)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if service_account_id is not None:
            pulumi.set(__self__, "service_account_id", service_account_id)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="roleUid")
    def role_uid(self) -> pulumi.Input[builtins.str]:
        """
        the role UID onto which to assign an actor
        """
        return pulumi.get(self, "role_uid")

    @role_uid.setter
    def role_uid(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role_uid", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the service account onto which the role is to be assigned
        """
        return pulumi.get(self, "service_account_id")

    @service_account_id.setter
    def service_account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_account_id", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the team onto which the role is to be assigned
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the user onto which the role is to be assigned
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _RoleAssignmentItemState:
    def __init__(__self__, *,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 role_uid: Optional[pulumi.Input[builtins.str]] = None,
                 service_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering RoleAssignmentItem resources.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        :param pulumi.Input[builtins.str] role_uid: the role UID onto which to assign an actor
        :param pulumi.Input[builtins.str] service_account_id: the service account onto which the role is to be assigned
        :param pulumi.Input[builtins.str] team_id: the team onto which the role is to be assigned
        :param pulumi.Input[builtins.str] user_id: the user onto which the role is to be assigned
        """
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if role_uid is not None:
            pulumi.set(__self__, "role_uid", role_uid)
        if service_account_id is not None:
            pulumi.set(__self__, "service_account_id", service_account_id)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter(name="roleUid")
    def role_uid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the role UID onto which to assign an actor
        """
        return pulumi.get(self, "role_uid")

    @role_uid.setter
    def role_uid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_uid", value)

    @property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the service account onto which the role is to be assigned
        """
        return pulumi.get(self, "service_account_id")

    @service_account_id.setter
    def service_account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_account_id", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the team onto which the role is to be assigned
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        the user onto which the role is to be assigned
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)


warnings.warn("""grafana.index/roleassignmentitem.RoleAssignmentItem has been deprecated in favor of grafana.enterprise/roleassignmentitem.RoleAssignmentItem""", DeprecationWarning)


@pulumi.type_token("grafana:index/roleAssignmentItem:RoleAssignmentItem")
class RoleAssignmentItem(pulumi.CustomResource):
    warnings.warn("""grafana.index/roleassignmentitem.RoleAssignmentItem has been deprecated in favor of grafana.enterprise/roleassignmentitem.RoleAssignmentItem""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 role_uid: Optional[pulumi.Input[builtins.str]] = None,
                 service_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages a single assignment for a role. Conflicts with the "enterprise.RoleAssignment" resource which manages the entire set of assignments for a role.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_role = grafana.enterprise.Role("test_role",
            name="Test Role",
            uid="testrole",
            version=1,
            global_=True,
            permissions=[{
                "action": "org.users:add",
                "scope": "users:*",
            }])
        test_team = grafana.oss.Team("test_team", name="terraform_test_team")
        test_user = grafana.oss.User("test_user",
            email="terraform_user@test.com",
            login="terraform_user@test.com",
            password="password")
        test_sa = grafana.oss.ServiceAccount("test_sa",
            name="terraform_test_sa",
            role="Viewer")
        user = grafana.enterprise.RoleAssignmentItem("user",
            role_uid=test_role.uid,
            user_id=test_user.id)
        team = grafana.enterprise.RoleAssignmentItem("team",
            role_uid=test_role.uid,
            team_id=test_team.id)
        service_account = grafana.enterprise.RoleAssignmentItem("service_account",
            role_uid=test_role.uid,
            service_account_id=test_sa.id)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/roleAssignmentItem:RoleAssignmentItem name "{{ roleUID }}:{{ type (user, team or service_account) }}:{{ identifier }}"
        ```

        ```sh
        $ pulumi import grafana:index/roleAssignmentItem:RoleAssignmentItem name "{{ orgID }}:{{ roleUID }}:{{ type (user, team or service_account) }}:{{ identifier }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        :param pulumi.Input[builtins.str] role_uid: the role UID onto which to assign an actor
        :param pulumi.Input[builtins.str] service_account_id: the service account onto which the role is to be assigned
        :param pulumi.Input[builtins.str] team_id: the team onto which the role is to be assigned
        :param pulumi.Input[builtins.str] user_id: the user onto which the role is to be assigned
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleAssignmentItemArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a single assignment for a role. Conflicts with the "enterprise.RoleAssignment" resource which manages the entire set of assignments for a role.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        test_role = grafana.enterprise.Role("test_role",
            name="Test Role",
            uid="testrole",
            version=1,
            global_=True,
            permissions=[{
                "action": "org.users:add",
                "scope": "users:*",
            }])
        test_team = grafana.oss.Team("test_team", name="terraform_test_team")
        test_user = grafana.oss.User("test_user",
            email="terraform_user@test.com",
            login="terraform_user@test.com",
            password="password")
        test_sa = grafana.oss.ServiceAccount("test_sa",
            name="terraform_test_sa",
            role="Viewer")
        user = grafana.enterprise.RoleAssignmentItem("user",
            role_uid=test_role.uid,
            user_id=test_user.id)
        team = grafana.enterprise.RoleAssignmentItem("team",
            role_uid=test_role.uid,
            team_id=test_team.id)
        service_account = grafana.enterprise.RoleAssignmentItem("service_account",
            role_uid=test_role.uid,
            service_account_id=test_sa.id)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/roleAssignmentItem:RoleAssignmentItem name "{{ roleUID }}:{{ type (user, team or service_account) }}:{{ identifier }}"
        ```

        ```sh
        $ pulumi import grafana:index/roleAssignmentItem:RoleAssignmentItem name "{{ orgID }}:{{ roleUID }}:{{ type (user, team or service_account) }}:{{ identifier }}"
        ```

        :param str resource_name: The name of the resource.
        :param RoleAssignmentItemArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleAssignmentItemArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 role_uid: Optional[pulumi.Input[builtins.str]] = None,
                 service_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 user_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""RoleAssignmentItem is deprecated: grafana.index/roleassignmentitem.RoleAssignmentItem has been deprecated in favor of grafana.enterprise/roleassignmentitem.RoleAssignmentItem""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleAssignmentItemArgs.__new__(RoleAssignmentItemArgs)

            __props__.__dict__["org_id"] = org_id
            if role_uid is None and not opts.urn:
                raise TypeError("Missing required property 'role_uid'")
            __props__.__dict__["role_uid"] = role_uid
            __props__.__dict__["service_account_id"] = service_account_id
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["user_id"] = user_id
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/roleAssignmentItem:RoleAssignmentItem")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(RoleAssignmentItem, __self__).__init__(
            'grafana:index/roleAssignmentItem:RoleAssignmentItem',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            org_id: Optional[pulumi.Input[builtins.str]] = None,
            role_uid: Optional[pulumi.Input[builtins.str]] = None,
            service_account_id: Optional[pulumi.Input[builtins.str]] = None,
            team_id: Optional[pulumi.Input[builtins.str]] = None,
            user_id: Optional[pulumi.Input[builtins.str]] = None) -> 'RoleAssignmentItem':
        """
        Get an existing RoleAssignmentItem resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        :param pulumi.Input[builtins.str] role_uid: the role UID onto which to assign an actor
        :param pulumi.Input[builtins.str] service_account_id: the service account onto which the role is to be assigned
        :param pulumi.Input[builtins.str] team_id: the team onto which the role is to be assigned
        :param pulumi.Input[builtins.str] user_id: the user onto which the role is to be assigned
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleAssignmentItemState.__new__(_RoleAssignmentItemState)

        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["role_uid"] = role_uid
        __props__.__dict__["service_account_id"] = service_account_id
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["user_id"] = user_id
        return RoleAssignmentItem(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[builtins.str]:
        """
        The Organization ID. If not set, the default organization is used for basic authentication, or the one that owns your service account for token authentication.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="roleUid")
    def role_uid(self) -> pulumi.Output[builtins.str]:
        """
        the role UID onto which to assign an actor
        """
        return pulumi.get(self, "role_uid")

    @property
    @pulumi.getter(name="serviceAccountId")
    def service_account_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        the service account onto which the role is to be assigned
        """
        return pulumi.get(self, "service_account_id")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        the team onto which the role is to be assigned
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        the user onto which the role is to be assigned
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .aws_account import *
from .aws_cloudwatch_scrape_job import *
from .aws_resource_metadata_scrape_job import *
from .azure_credential import *
from .get_aws_account import *
from .get_aws_cloudwatch_scrape_job import *
from .get_aws_cloudwatch_scrape_jobs import *
from .get_azure_credential import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetTeamResult',
    'AwaitableGetTeamResult',
    'get_team',
    'get_team_output',
]

@pulumi.output_type
class GetTeamResult:
    """
    A collection of values returned by getTeam.
    """
    def __init__(__self__, avatar_url=None, email=None, id=None, name=None):
        if avatar_url and not isinstance(avatar_url, str):
            raise TypeError("Expected argument 'avatar_url' to be a str")
        pulumi.set(__self__, "avatar_url", avatar_url)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="avatarUrl")
    def avatar_url(self) -> builtins.str:
        return pulumi.get(self, "avatar_url")

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The team name.
        """
        return pulumi.get(self, "name")


class AwaitableGetTeamResult(GetTeamResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTeamResult(
            avatar_url=self.avatar_url,
            email=self.email,
            id=self.id,
            name=self.name)


def get_team(name: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTeamResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    my_team = grafana.oss.get_team(name="my team")
    my_team_get_team = grafana.onCall.get_team(name=my_team.name)
    ```


    :param builtins.str name: The team name.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:onCall/getTeam:getTeam', __args__, opts=opts, typ=GetTeamResult).value

    return AwaitableGetTeamResult(
        avatar_url=pulumi.get(__ret__, 'avatar_url'),
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_team_output(name: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTeamResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    my_team = grafana.oss.get_team(name="my team")
    my_team_get_team = grafana.onCall.get_team(name=my_team.name)
    ```


    :param builtins.str name: The team name.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:onCall/getTeam:getTeam', __args__, opts=opts, typ=GetTeamResult)
    return __ret__.apply(lambda __response__: GetTeamResult(
        avatar_url=pulumi.get(__response__, 'avatar_url'),
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))
